@@ -9,11 +9,9 @@ mod lex;
 mod parse;
 mod scope;
 mod shapes;
-mod signature;
 
-pub use lex::lexer::{lex, parse_block};
+pub use lex::lexer::{lex, parse_block, NewlineMode};
 pub use lex::tokens::{LiteBlock, LiteCommand, LiteGroup, LitePipeline};
 pub use parse::{classify_block, garbage, parse, parse_full_column_path, parse_math_expression};
 pub use scope::ParserScope;
 pub use shapes::shapes;
-pub use signature::{Signature, SignatureRegistry};
